
/*	Copyright (C) 2005, 2006 by Andy Grebe a.k.a. tecknophreak(tecknophreak@gmail.com)
 *
 *	This file is part of TouchMe Games.
 *
 *	TouchMe Games is free software; you can redistribute it and/or modify
 *	it under the terms of the GNU General Public License as published by
 *	the Free Software Foundation; either version 2 of the License, or
 *	(at your option) any later version.
 *
 *	TouchMe Games is distributed in the hope that it will be useful,
 *	but WITHOUT ANY WARRANTY; without even the implied warranty of
 *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *	GNU General Public License for more details.
 *
 *	You should have received a copy of the GNU General Public License
 *	along with TouchMe Games; if not, write to the Free Software
 *	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
 

// events for DART_01

#include <dart01.h>
#include <algorithm>
#include <sstream>
#include <iostream>
#include <iomanip>


void DART_01::exitGame(GtkWidget *widget, GdkEvent *event, gpointer ptr) {
	DART_01 *g(reinterpret_cast<DART_01 *>(ptr));
	SCORE_STRUCT newScore;
	
	newScore.name = "";
	newScore.fscore = g->highScore;
	newScore.date = "";
	
	g->GAME_PTR::addScore(g->scores, newScore);
	
	
	g->GAME_PTR::saveScores(g->scores);
	
	gtk_widget_hide(g->fixed);
	
	g_source_remove(g->timer);
	gtk_widget_destroy(g->popupMenu);
	
	g->dartBoard.closeDart();
}

void DART_01::showMenu(GtkWidget *widget, GdkEvent *event, gpointer ptr) {
	DART_01 *dart(reinterpret_cast<DART_01 *>(ptr));
	if (dart->gameState == PLAYING) {
		dart->dartBoard.pause();
		gtk_window_set_keep_above((GtkWindow *)dart->popupMenu, TRUE);
		gtk_widget_show_all(dart->popupMenu);
	}
}

gboolean DART_01::eventPressed(GtkWidget *widget, GdkEventKey *event, gpointer ptr) {
	DART_01 *dart(reinterpret_cast<DART_01 *>(ptr));
	gtk_widget_modify_style(widget, dart->menuDown);
	return FALSE;
}

gboolean DART_01::missedDartReleased(GtkWidget *widget, GdkEventKey *event, gpointer ptr) {
	DART_01 *dart(reinterpret_cast<DART_01 *>(ptr));
	std::stringstream sstr;
	std::cout << __FILE__ << ' ' << __LINE__ << std::endl;
	std::cout.flush();
	
	gtk_widget_modify_style(widget, dart->menuUp);
	dart->dartBoard.unpause();
	gtk_widget_hide(dart->popupMenu);
	
	std::cout << __FILE__ << ' ' << __LINE__ << std::endl;
	std::cout.flush();
	
	++dart->darts[dart->currentPlayer];
		
	sstr << "Missed";
	std::cout << __FILE__ << ' ' << __LINE__ << std::endl;
	std::cout.flush();
	
	dart->addDart(0, 0);
	
	gtk_label_set_text((GtkLabel *)dart->dartLabels[dart->currentDart], sstr.str().c_str());
	gtk_widget_show(dart->dartLabels[dart->currentDart]);
		
	gtk_widget_hide(dart->dartImages[dart->currentDart++]);
	
	std::cout << __FILE__ << ' ' << __LINE__ << std::endl;
	std::cout.flush();
	return FALSE;
}

gboolean DART_01::removeLastDartReleased(GtkWidget *widget, GdkEventKey *event, gpointer ptr) {
	DART_01 *dart(reinterpret_cast<DART_01 *>(ptr));
	
	
	gtk_widget_modify_style(widget, dart->menuUp);
	
	if (dart->lastDartScore[0] != -1) {
		GtkWidget *dialog;
		GtkWidget *label;
		GtkRcStyle *whiteStyle;
		GtkWidget *ok, *cancel;
		GdkColor color;
		std::stringstream sstr;
		
		dialog = gtk_dialog_new();
		gtk_widget_modify_bg(dialog, (GtkStateType)0, &dart->bgcolor);
		
		whiteStyle = gtk_rc_style_new();
		whiteStyle->font_desc = pango_font_description_new();
		pango_font_description_set_size(whiteStyle->font_desc, 28 * PANGO_SCALE);
		pango_font_description_set_weight(whiteStyle->font_desc, PANGO_WEIGHT_BOLD);
		color.red = 0xFFFF;
		color.green = 0xFFFF;
		color.blue = 0xFFFF;
		whiteStyle->fg[0] = color;
		whiteStyle->color_flags[0] = GTK_RC_FG;
		
		sstr << "Are you sure you want to delete a ";
		if (dart->lastDartMult[0] != 0) {
			if (dart->lastDartMult[0] == 1) {
				sstr << "single ";
			}
			else if (dart->lastDartMult[0] == 2) {
				sstr << "double ";
			}
			else if (dart->lastDartMult[0] == 3) {
				sstr << "triple ";
			}
			if (dart->lastDartScore[0] != 25) {
				sstr << dart->lastDartScore[0];
			}
			else {
				sstr << " bull";
			}
		}
		else {
			sstr << "missed.";
		}
		sstr << "?";
		label = gtk_label_new(sstr.str().c_str());
		gtk_widget_modify_style(label, whiteStyle);
		
		gtk_box_pack_start((GtkBox *)GTK_DIALOG(dialog)->vbox, label, FALSE, FALSE, 0);
		
		ok = gtk_button_new();
		label = gtk_label_new("OK");
		gtk_widget_modify_style(label, whiteStyle);
		gtk_container_add((GtkContainer *)ok, label);
		
		gtk_dialog_add_action_widget((GtkDialog *)dialog, ok, 0);
		
		cancel = gtk_button_new();
		label = gtk_label_new("Cancel");
		gtk_widget_modify_style(label, whiteStyle);
		gtk_container_add((GtkContainer *)cancel, label);
		
		gtk_dialog_add_action_widget((GtkDialog *)dialog, cancel, 1);
		
		
		gtk_widget_show_all(dialog);
		if (gtk_dialog_run((GtkDialog *)dialog) == 0) {
			dart->resyncGame();
			dart->removeDart();
		}
		gtk_widget_destroy(dialog);
		
		std::cout << "Last Dart: " << dart->lastDartScore[0] << ' ' << dart->lastDartMult[0] << std::endl;
  pango_font_description_free(whiteStyle->font_desc);
	}
	
	dart->dartBoard.unpause();
	gtk_widget_hide(dart->popupMenu);
	return FALSE;
}

gboolean DART_01::exitGameReleased(GtkWidget *widget, GdkEventKey *event, gpointer ptr) {
	DART_01 *dart(reinterpret_cast<DART_01 *>(ptr));
	
	gtk_widget_modify_style(widget, dart->menuUp);
	gtk_widget_destroy(dart->popupMenu);
	g_source_remove(dart->timer);
	dart->dartBoard.closeDart();
	gtk_widget_hide(dart->fixed);
	
	return FALSE;
}

gboolean DART_01::cancelReleased(GtkWidget *widget, GdkEventKey *event, gpointer ptr) {
	DART_01 *dart(reinterpret_cast<DART_01 *>(ptr));
	dart->dartBoard.unpause();
	gtk_widget_modify_style(widget, dart->menuUp);
	gtk_widget_hide(dart->popupMenu);
	return FALSE;
}

void DART_01::addDart(int score, int mult) {
	int rh;
	// we place the darts in 0 - 9
	std::cout << "Adding dart: " << score << ' ' << mult << std::endl;
	for (rh = 0; lastDartScore[rh] != -1 && rh < 5; ++rh);
	if (rh != 0 && rh != 5) {
		++rh;
	}
	
	for (rh -= 1; rh > 0; --rh) {
		lastDartScore[rh] = lastDartScore[rh - 1];
		lastDartMult[rh] = lastDartMult[rh - 1];
	}
	lastDartScore[0] = score;
	lastDartMult[0] = mult;
}

void DART_01::removeDart() {
	int lh(0), rh;
	
	// find the last valid dart
	for (rh = 0; lastDartScore[rh] != -1 && rh < 5; ++rh);
	--rh;
	for (lh = 0; lh < rh; ++lh) {
		lastDartScore[lh] = lastDartScore[lh + 1];
		lastDartMult[lh] = lastDartMult[lh + 1];
	}
	lastDartScore[rh] = -1;
	lastDartMult[rh] = -1;
}

void DART_01::resyncGame() {
	
	// ok, first backup a dart
	std::cout << "Current Dart " << currentDart << ' ' << currentPlayer << std::endl;
	if (currentDart == 0) {
		std::stringstream sstr;
		int totScore;
		currentDart = 2;
		currentPlayer -= 1;
		if (currentPlayer < 0) {
			currentPlayer = numberOfPlayers - 1;
		}
		// things to think of
		// 1.  Remove the last dart for the player
		// 2.  Get the last current score for the player
		// 3.  What if it was a bust, then there should be nothing there
		totScore = atoi(gtk_label_get_text((GtkLabel *)playerScoreLabels[currentPlayer]));
		totScore += lastDartScore[0] * lastDartMult[0];
		currentScore = 0;
		if (lastDartScore[1] != -1) {
			currentScore += lastDartScore[1] * lastDartMult[1];
			if (lastDartScore[2] != -1) {
				currentScore += lastDartScore[2] * lastDartMult[2];
			}
		}
		sstr << totScore;
		gtk_label_set_text((GtkLabel *)playerScoreLabels[currentPlayer], sstr.str().c_str());
		gtk_label_set_text((GtkLabel *)currentTotalLabel, sstr.str().c_str());
		sstr.str("");
		sstr << currentScore;
		gtk_label_set_text((GtkLabel *)currentScoreLabel, sstr.str().c_str());
		if (lastDartMult[0] == 3) {
			--triples[currentPlayer];
		}
		else if (lastDartMult[0] == 2) {
			--doubles[currentPlayer];
		}
		if (lastDartScore[0] == 25) {
			--bulls[currentPlayer];
		}
		
		// now fill in the first dart or two the player hit
		if (lastDartScore[2] != -1) {
			// the player hit three darts total, fill in the first and second
			sstr.str("");
			if (lastDartMult[2] == 3) {
				sstr << "Triple ";
				if (lastDartScore[2] >= 25) {
					sstr << "BULL";
				}
				else {
					sstr << lastDartScore[2];
				}
			}
			else if (lastDartMult[2] == 2) {
				sstr << "Double ";
				if (lastDartScore[2] >= 25) {
					sstr << "BULL";
				}
				else {
					sstr << lastDartScore[2];
				}
			}
			else {
				sstr << "Single ";
				if (lastDartScore[2] >= 25) {
					sstr << "BULL";
				}
				else {
					sstr << lastDartScore[2];
				}
			}
			gtk_label_set_text((GtkLabel *)dartLabels[0], sstr.str().c_str());
			gtk_widget_show(dartLabels[0]);
			gtk_widget_hide(dartImages[0]);
			
			sstr.str("");
			if (lastDartMult[1] == 3) {
				sstr << "Triple ";
				if (lastDartScore[1] >= 25) {
					sstr << "BULL";
				}
				else {
					sstr << lastDartScore[1];
				}
			}
			else if (lastDartMult[1] == 2) {
				sstr << "Double ";
				if (lastDartScore[1] >= 25) {
					sstr << "BULL";
				}
				else {
					sstr << lastDartScore[1];
				}
			}
			else {
				sstr << "Single ";
				if (lastDartScore[1] >= 25) {
					sstr << "BULL";
				}
				else {
					sstr << lastDartScore[1];
				}
			}
			gtk_label_set_text((GtkLabel *)dartLabels[1], sstr.str().c_str());
			gtk_widget_show(dartLabels[1]);
			gtk_widget_hide(dartImages[1]);
			
		}
		else if (lastDartScore[1] != -1) {
			sstr.str("");
			if (lastDartMult[1] == 3) {
				sstr << "Triple ";
				if (lastDartScore[1] >= 25) {
					sstr << "BULL";
				}
				else {
					sstr << lastDartScore[1];
				}
			}
			else if (lastDartMult[1] == 2) {
				sstr << "Double ";
				if (lastDartScore[1] >= 25) {
					sstr << "BULL";
				}
				else {
					sstr << lastDartScore[1];
				}
			}
			else {
				sstr << "Single ";
				if (lastDartScore[1] >= 25) {
					sstr << "BULL";
				}
				else {
					sstr << lastDartScore[1];
				}
			}
			gtk_label_set_text((GtkLabel *)dartLabels[0], sstr.str().c_str());
			gtk_widget_show(dartLabels[0]);
			gtk_widget_hide(dartImages[0]);
			
		}
		sstr.str("");
		sstr << "Round " << --round;
		gtk_label_set_text((GtkLabel *)roundLabel, sstr.str().c_str());
		--rounds[currentPlayer];
		--darts[currentPlayer];
	}
	else {
		std::stringstream sstr;
		int totScore;
		totScore = atoi(gtk_label_get_text((GtkLabel *)playerScoreLabels[currentPlayer]));
		std::cout << "Game resync" << std::endl;
		--currentDart;
		gtk_widget_hide(dartLabels[currentDart]);
		gtk_widget_show(dartImages[currentDart]);
		std::cout << "Last Dart... " << lastDartScore[0] * lastDartMult[0] << std::endl;
		currentScore -= lastDartScore[0] * lastDartMult[0];
		totScore += lastDartScore[0] * lastDartMult[0];
		sstr << totScore;
		gtk_label_set_text((GtkLabel *)playerScoreLabels[currentPlayer], sstr.str().c_str());
		gtk_label_set_text((GtkLabel *)currentTotalLabel, sstr.str().c_str());
		sstr.str("");
		sstr << currentScore;
		gtk_label_set_text((GtkLabel *)currentScoreLabel, sstr.str().c_str());
		--darts[currentPlayer];
		if (lastDartMult[0] == 3) {
			--triples[currentPlayer];
		}
		else if (lastDartMult[0] == 2) {
			--doubles[currentPlayer];
		}
		if (lastDartScore[0] == 25) {
			--bulls[currentPlayer];
		}
	}
	
	// place the dart back where it was
}

gboolean DART_01::timeout(gpointer ptr) {
	DART_01 *dart(reinterpret_cast<DART_01 *>(ptr));
	int score, totScore;
	std::stringstream sstr;
	
	if (dart->gameState == DROPPING_LOW_TON) {
		if (dart->lowTonY == 300) {
			if (++dart->currentDart > 43) {
				dart->currentDart = 22;
				dart->gameState = BETWEEN_ROUNDS;
				gtk_fixed_move((GtkFixed *)dart->fixed, dart->lowTon, 250, -300);
				dart->didTon = true;
			}
			return TRUE;
		}
		dart->lowTonY += 50;
		std::cout << "Dart lowtony " << dart->lowTonY << std::endl;
		gtk_fixed_move((GtkFixed *)dart->fixed, dart->lowTon, 250, dart->lowTonY);
		return TRUE;
	}
	else if (dart->gameState == DROPPING_HIGH_TON) {
		if (dart->highTonY == 200) {
			if (++dart->currentDart > 43) {
				dart->currentDart = 22;
				dart->gameState = BETWEEN_ROUNDS;
				gtk_fixed_move((GtkFixed *)dart->fixed, dart->highTon, 200, -400);
				dart->didTon = true;
			}
			return TRUE;
		}
		dart->highTonY += 50;
		gtk_fixed_move((GtkFixed *)dart->fixed, dart->highTon, 200, dart->highTonY);
		return TRUE;
	}
	else if (dart->gameState == DROPPING_TON_80) {
		if (dart->ton80Y == 0) {
			if (++dart->currentDart > 43) {
				dart->currentDart = 22;
				dart->gameState = BETWEEN_ROUNDS;
				gtk_fixed_move((GtkFixed *)dart->fixed, dart->ton80, 100, -600);
				dart->didTon = true;
			}
			return TRUE;
		}
		dart->ton80Y += 50;
		gtk_fixed_move((GtkFixed *)dart->fixed, dart->ton80, 100, dart->ton80Y);
		return TRUE;
	}
	
	if (dart->currentDart <= 2 && dart->gameState == PLAYING) {
		int a, x(0);
		if (!dart->dartBoard.gotDart()) {
			return TRUE;
		}
		dart->dartBoard.readDart(x, a);
		
		if (a == 2) {
			++dart->doubles[dart->currentPlayer];
		}
		else if (a == 3) {
			++dart->triples[dart->currentPlayer];
		}
		
		if (x > 20) {
			std::cout << "Plus Plus Bulls" << std::endl;
			++dart->bulls[dart->currentPlayer];
		}
		
		score = x * a;
		
		// Incoming dart
		totScore = atoi(gtk_label_get_text((GtkLabel *)dart->playerScoreLabels[dart->currentPlayer]));
		totScore -= score;
		++dart->darts[dart->currentPlayer];
		if (totScore < 0) {
			gtk_label_set_text((GtkLabel *)dart->currentTotalLabel, "BUST");
			
			sstr.str("");
			sstr << dart->beginningScore;
			std::cout << "Dart-beginning Score " << dart->beginningScore << std::endl;
			gtk_label_set_text((GtkLabel *)dart->playerScoreLabels[dart->currentPlayer], sstr.str().c_str());
			
			sstr.str("");
			if (a == 1) {
				sstr << "Single ";
				if (x < 25) {
					sstr << score;
				}
				else {
					sstr << "BULL";
				}
			}
			else if (a == 2) {
				sstr << "Double ";
				if (x < 25) {
					sstr << score / a;
				}
				else {
					sstr << "BULL";
				}
			}
			else if (a == 3) {
				sstr << "Triple " << score / a;
				
			}
			gtk_label_set_text((GtkLabel *)dart->dartLabels[dart->currentDart], sstr.str().c_str());
			gtk_widget_show(dart->dartLabels[dart->currentDart]);
			gtk_widget_hide(dart->dartImages[dart->currentDart]);
			
			for (int i = dart->currentDart; i; --i) {
				dart->removeDart();
			}
			
			dart->currentDart = 3;
			dart->gameState = BETWEEN_ROUNDS;
		}
		else {
			sstr << totScore;
			
			dart->addDart(x, a);
			
			gtk_label_set_text((GtkLabel *)dart->playerScoreLabels[dart->currentPlayer], sstr.str().c_str());
			gtk_label_set_text((GtkLabel *)dart->currentTotalLabel, sstr.str().c_str());
			dart->currentScore += score;
			
			sstr.str("");
			if (a == 1) {
				sstr << "Single ";
				if (x < 25) {
					sstr << score;
				}
				else {
					sstr << "BULL";
				}
			}
			else if (a == 2) {
				sstr << "Double ";
				if (x < 25) {
					sstr << score / a;
				}
				else {
					sstr << "BULL";
				}
			}
			else if (a == 3) {
				sstr << "Triple " << score / a;
				
			}
			gtk_label_set_text((GtkLabel *)dart->dartLabels[dart->currentDart], sstr.str().c_str());
			gtk_widget_show(dart->dartLabels[dart->currentDart]);
			
			sstr.str("");
			sstr << dart->currentScore;
			gtk_label_set_text((GtkLabel *)dart->currentScoreLabel, sstr.str().c_str());
			gtk_widget_hide(dart->dartImages[dart->currentDart++]);
			
		}
		if (totScore == 0) {
			std::cout << "Game Over!!" << std::endl;
			
			++dart->rounds[dart->currentPlayer];
			dart->winner = dart->currentPlayer;
			
			if (!dart->lastChanceDarts) {
				dart->gameState = GAME_OVER1;
				std::cout << "Winner " << dart->winner << ' ' << dart->currentPlayer << std::endl;
				dart->createGameOver1();
				return FALSE;
			}
			else {
				dart->currentDart = 3;
				dart->gameState = BETWEEN_ROUNDS;
			}
		}
	}
	else {
		if (dart->currentDart == 3) {
			int player;
			float ppd(0.0), points;
			dart->dartBoard.pause();
			dart->gameState = BETWEEN_ROUNDS;
			// PPD Above each player's score
			++dart->rounds[dart->currentPlayer];
			player = dart->currentPlayer;
			points = (dart->dartGameType - atoi(gtk_label_get_text(
					(GtkLabel *)dart->playerScoreLabels[player])));
			
			if (dart->darts[player]) {
				ppd = points / (float)(dart->darts[player]);
			}
			else {
				ppd = 0.0;
			}
			
			sstr.str("");
			sstr << "Player " << player + 1 << " - " << std::setprecision(3) << ppd;
			gtk_label_set_text((GtkLabel *)dart->playerLabels[player], sstr.str().c_str());
		}
		else if (dart->currentDart == 23) {
			int player, p;
			float ppd(0.0), points;
			
			
			p = atoi(gtk_label_get_text((GtkLabel *)dart->currentScoreLabel));
			if ((p == 180) && !dart->didTon) {
				++dart->ton80s[dart->currentPlayer];
				dart->maxTon[dart->currentPlayer] = 180;
				dart->createTon80();
				dart->gameState = DROPPING_TON_80;
				return TRUE;
			}
			else if ((p > 149) && !dart->didTon) {
				++dart->highTons[dart->currentPlayer];
				if (p > dart->maxTon[dart->currentPlayer]) {
					dart->maxTon[dart->currentPlayer] = p;
				}
				dart->createHighTon();
				dart->gameState = DROPPING_HIGH_TON;
				return TRUE;
			}
			else if (p > 99 && !dart->didTon) {
				++dart->lowTons[dart->currentPlayer];
				if (p > dart->maxTon[dart->currentPlayer]) {
					dart->maxTon[dart->currentPlayer] = p;
				}
				dart->createLowTon();
				dart->gameState = DROPPING_LOW_TON;
				return TRUE;
			}
			dart->didTon = false;
			
			// get the next player's PPD going
			if (dart->currentPlayer + 1 == dart->numberOfPlayers) {
				player = 0;
				std::cout << "Winner: " << dart->winner << ' ' <<  __LINE__ << std::endl;
				if (dart->winner >= 0) {
					dart->gameState = GAME_OVER1;
					dart->createGameOver1();
					return FALSE;
				}
			}
			else {
				player = dart->currentPlayer + 1;
			}
			
			points = (dart->dartGameType - atoi(gtk_label_get_text(
					(GtkLabel *)dart->playerScoreLabels[player])));
			
			if (dart->darts[player]) {
				ppd = points / (float)(dart->darts[player]);
			}
			else {
				ppd = 0.0;
			}
			sstr.str("");
			sstr << "Player " << player + 1;
			gtk_label_set_text((GtkLabel *)dart->ppdPlayerLabel, sstr.str().c_str());
			
			sstr.str("");
			sstr << "PPD: " << std::setprecision(3) << ppd;
			
			gtk_label_set_text((GtkLabel *)dart->ppdLabel, sstr.str().c_str());
			
			gtk_widget_show_all(dart->ppdWindow);
			
		}
		++dart->currentDart;
	}
	if (dart->currentDart == 43) {
		dart->currentDart = 0;
		gtk_widget_show(dart->dartImages[0]);
		gtk_widget_show(dart->dartImages[1]);
		gtk_widget_show(dart->dartImages[2]);
		gtk_widget_hide(dart->dartLabels[0]);
		gtk_widget_hide(dart->dartLabels[1]);
		gtk_widget_hide(dart->dartLabels[2]);
		dart->currentScore = 0;
		gtk_label_set_text((GtkLabel *)dart->currentScoreLabel, "0");
		
		if (++dart->currentPlayer == dart->numberOfPlayers) {
			dart->currentPlayer = 0;
			++dart->round;
			sstr.str("");
			sstr << "Round " << std::setw(3) << dart->round;
			gtk_label_set_text((GtkLabel *)dart->roundLabel, sstr.str().c_str());
			
		}
		dart->beginningScore = atoi(gtk_label_get_text((GtkLabel *)dart->playerScoreLabels[dart->currentPlayer]));
		gtk_label_set_text((GtkLabel *)dart->currentTotalLabel,
				    gtk_label_get_text((GtkLabel *)dart->playerScoreLabels[dart->currentPlayer]));
		
		sstr.str("");
		sstr << "Player " << dart->currentPlayer + 1 << " Score";
		gtk_label_set_text((GtkLabel *)dart->playerLabel, sstr.str().c_str());
		gtk_widget_hide_all(dart->ppdWindow);
		dart->gameState = PLAYING;
		dart->dartBoard.unpause();
	}
	return TRUE;
}

void DART_01::changeNumPlayers(GtkWidget *widget, gpointer ptr) {
	std::stringstream sstr;
	int i(atoi(gtk_entry_get_text((GtkEntry *)ptr)));
	if (++i > 8) {
		i = 1;
	}
	sstr << i;
	gtk_entry_set_text((GtkEntry *)ptr, sstr.str().c_str());
}

void DART_01::changeGame(GtkWidget *widget, gpointer ptr) {
	std::stringstream sstr;
	int i(atoi(gtk_entry_get_text((GtkEntry *)ptr)));
	i += 100;
	if (i == 1001) {
		i = 101;
	}
	
	sstr << i;
	gtk_entry_set_text((GtkEntry *)ptr, sstr.str().c_str());
}

void DART_01::onOffToggle(GtkWidget *widget, gpointer ptr) {
	std::string str;
	str = gtk_label_get_text((GtkLabel *)ptr);
	if (str[1] == 'n') {
		gtk_label_set_text((GtkLabel *)ptr, "Off");
	}
	else {
		gtk_label_set_text((GtkLabel *)ptr, "On");
	}
}

void DART_01::startGame(GtkWidget *widget, gpointer ptr) {
	DART_01 *dart((DART_01 *)ptr);
	dart->dartGameType = atoi(gtk_entry_get_text((GtkEntry *)dart->gameTypeEntry));
	
	dart->doubleBullOn = strcmp(gtk_label_get_text((GtkLabel *)dart->doubleBullLabel), "On") == 0 ? true: false;
	dart->lastChanceDarts = strcmp(gtk_label_get_text((GtkLabel *)dart->lastChanceLabel), "On") == 0 ? true: false;
	dart->numberOfPlayers = atoi(gtk_entry_get_text((GtkEntry *)dart->numPlayersEntry));
	((DART_01 *)ptr)->initScreen();
	dart->dartBoard.setDoubleBull(dart->doubleBullOn);
}

